Struct ExtSessionLockSurfaceV1

pub struct ExtSessionLockSurfaceV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
a surface displayed while the session is locked

The client may use lock surfaces to display a screensaver, render a dialog to enter a password and unlock the session, or however else it sees fit.

On binding this interface the compositor will immediately send the first configure event. After making the ack_configure request in response to this event the client should attach and commit the first buffer. Committing the surface before acking the first configure is a protocol error. Committing the surface with a null buffer at any time is a protocol error.

The compositor is free to handle keyboard/pointer focus for lock surfaces however it chooses. A reasonable way to do this would be to give the first lock surface created keyboard focus and change keyboard focus if the user clicks on other surfaces.

See also the Event enum for this interface.

Implementations



impl ExtSessionLockSurfaceV1

pub fn destroy(&self)

destroy the lock surface object

This informs the compositor that the lock surface object will no longer be used.

It is recommended for a lock client to destroy lock surfaces if their corresponding wl_output global is removed.

If a lock surface on an active output is destroyed before the ext_session_lock_v1.unlock_and_destroy event is sent, the compositor must fall back to rendering a solid color.

pub fn ack_configure(&self, serial: u32)

ack a configure event

When a configure event is received, if a client commits the surface in response to the configure event, then the client must make an ack_configure request sometime before the commit request, passing along the serial of the configure event.

If the client receives multiple configure events before it can respond to one, it only has to ack the last configure event.

A client is not required to commit immediately after sending an ack_configure request - it may even ack_configure several times before its next surface commit.

A client may send multiple ack_configure requests before committing, but only the last request sent before a commit indicates which configure event the client really is responding to.

Sending an ack_configure request consumes the configure event referenced by the given serial, as well as all older configure events sent on this object.

It is a protocol error to issue multiple ack_configure requests referencing the same configure event or to issue an ack_configure request referencing a configure event older than the last configure event acked for a given lock surface.